==> owncloud-8.2.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/nds.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Holen des Requesttokens fehlgeschlagen. Bitte überprüfe Schlüssel und Secret deiner App.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Holen des Zugrifftokens fehlgeschlagen. Bitte überprüfe Schlüssel und Secret deiner App.",
    "Please provide a valid app key and secret." : "Bitte verwende für deine App einen gültigen Schüssel und ein gültiges Secret.",
    "Step 1 failed. Exception: %s" : "Schritt 1 fehlgeschlagen. Exception: %s",
    "Step 2 failed. Exception: %s" : "Schritt 2 fehlgeschlagen. Exception: %s",
    "External storage" : "Externer Speicher",
    "Storage with id \"%i\" not found" : "Speicher mit der ID \"%i\" wurde nicht gefunden",
    "Invalid backend or authentication mechanism class" : "Ungültige Klasse für das Backend oder für den Authentifizierungsmechanismus",
    "Invalid mount point" : "Ungültiger Einhängepunkt",
    "Objectstore forbidden" : "Objectstore nicht erlaubt",
    "Invalid storage backend \"%s\"" : "Ungültiges Speicherbackend \"%s\"",
    "Not permitted to use backend \"%s\"" : "Verwendung des Backends \"%s\" nicht erlaubt",
    "Not permitted to use authentication mechanism \"%s\"" : "Verwendung des Authentifizierungsmechanismus \"%s\" nicht erlaubt",
    "Unsatisfied backend parameters" : "Nicht bediente Backendparameter",
    "Unsatisfied authentication mechanism parameters" : "Nicht bediente Authentifizierungsmechanismusparamter",
    "Personal" : "Persönlich",
    "System" : "System",
    "Grant access" : "Erlaube Zugriff",
    "Access granted" : "Zugriff erlaubt",
    "Error configuring OAuth1" : "Fehler bei der Konfiguration von OAuth1",
    "Error configuring OAuth2" : "Fehler bei der Konfiguration von OAuth2",
    "Generate keys" : "Generiere Schlüssel",
    "Error generating key pair" : "Fehler beim Generieren des Schlüsselpaars",
    "Enable encryption" : "Verschlüsselung aktivieren",
    "Enable previews" : "Vorschau aktivieren",
    "Check for changes" : "Auf Änderungen prüfen",
    "Never" : "Nie",
    "Once every direct access" : "Einmal bei jedem direkten Zugriff",
    "Every time the filesystem is used" : "Bei jeder Verwendung des Dateisystems",
    "All users. Type to select user or group." : "Alle Benutzer. Tippe, um eine Benutzergruppe auszuwählen.",
    "(group)" : "(Gruppe)",
    "Saved" : "Gespeichert",
    "Access key" : "Schlüssel für Zugriff",
    "Secret key" : "Geheimer Schlüssel",
    "Builtin" : "Eingebaut",
    "None" : "Keine(r)",
    "OAuth1" : "OAuth1",
    "App key" : "App Schlüssel",
    "App secret" : "App Secret",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client ID",
    "Client secret" : "Client Geheimnis",
    "OpenStack" : "OpenStack",
    "Username" : "Benutzername",
    "Password" : "Passwort",
    "API key" : "API Schlüssel",
    "Username and password" : "Benutzername und Passwort",
    "Session credentials" : "Anmeldedaten der Sitzung",
    "RSA public key" : "Öffentlicher RSA Schlüssel",
    "Public key" : "Öffentlicher Schlüssel",
    "Amazon S3" : "Amazon S3",
    "Hostname" : "Hostname",
    "Port" : "Port",
    "Region" : "Region",
    "Enable SSL" : "SSL aktivieren",
    "Enable Path Style" : "Path Style aktivieren",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Entfernter Unterordner",
    "Secure https://" : "Sicheres https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Sicheres fpts://",
    "Google Drive" : "Google Drive",
    "Local" : "Lokal",
    "Location" : "Ort",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP mit Anmeldung über geheimen Schlüssel",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Teilen",
    "Domain" : "Domäne",
    "SMB / CIFS using OC login" : "SMB / DIFS mit OC Anmeldung",
    "Username as share" : "Benutzername als Freigabe",
    "Service name" : "Name des Dienstes",
    "Request timeout (seconds)" : "Zeitüberschreitung der Anfrage (Sekunden)",
    "<b>Note:</b> " : "<b>Notiz:</b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Notiz:</b> Die cURL-Unterstützung ist in PHP nicht aktiviert oder nicht installiert, deshalb ist das Einhängen von %s nicht möglich. Bitte deinen Administrator diese zu installieren.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Notiz:</b> Die FTP-Unterstützung ist in PHP nicht aktiviert oder nicht installiert, deshalb ist das Einhängen von %s nicht möglich. Bitte deinen Administrator diese zu installieren.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Notiz:</b> \"%s\" ist nicht installiert, deshalb ist das Einhängen von %s nicht möglich. Bitte deinen Administrator diese zu installieren.",
    "No external storage configured" : "Kein externer Speicher konfiguriert",
    "You can add external storages in the personal settings" : "Du kannst externe Speicher in deinen persönlichen Einstellungen hinzufügen",
    "Name" : "Name",
    "Storage type" : "Speicherart",
    "Scope" : "Bereich",
    "External Storage" : "Externer Speicher",
    "Folder name" : "Ordnername",
    "Authentication" : "Authentifizierung",
    "Configuration" : "Konfiguration",
    "Available for" : "Verfügbar für",
    "Advanced settings" : "Erweiterte Einstellungen",
    "Delete" : "Löschen",
    "Add storage" : "Speicher hinzufügen",
    "Enable User External Storage" : "Externen Speicher für Nutzer aktivieren",
    "Allow users to mount the following external storage" : "Erlaube Benutzern folgenden externen Speicher einzuhängen"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/nds.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Holen des Requesttokens fehlgeschlagen. Bitte überprüfe Schlüssel und Secret deiner App.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Holen des Zugrifftokens fehlgeschlagen. Bitte überprüfe Schlüssel und Secret deiner App.",
    "Please provide a valid app key and secret." : "Bitte verwende für deine App einen gültigen Schüssel und ein gültiges Secret.",
    "Step 1 failed. Exception: %s" : "Schritt 1 fehlgeschlagen. Exception: %s",
    "Step 2 failed. Exception: %s" : "Schritt 2 fehlgeschlagen. Exception: %s",
    "External storage" : "Externer Speicher",
    "Storage with id \"%i\" not found" : "Speicher mit der ID \"%i\" wurde nicht gefunden",
    "Invalid backend or authentication mechanism class" : "Ungültige Klasse für das Backend oder für den Authentifizierungsmechanismus",
    "Invalid mount point" : "Ungültiger Einhängepunkt",
    "Objectstore forbidden" : "Objectstore nicht erlaubt",
    "Invalid storage backend \"%s\"" : "Ungültiges Speicherbackend \"%s\"",
    "Not permitted to use backend \"%s\"" : "Verwendung des Backends \"%s\" nicht erlaubt",
    "Not permitted to use authentication mechanism \"%s\"" : "Verwendung des Authentifizierungsmechanismus \"%s\" nicht erlaubt",
    "Unsatisfied backend parameters" : "Nicht bediente Backendparameter",
    "Unsatisfied authentication mechanism parameters" : "Nicht bediente Authentifizierungsmechanismusparamter",
    "Personal" : "Persönlich",
    "System" : "System",
    "Grant access" : "Erlaube Zugriff",
    "Access granted" : "Zugriff erlaubt",
    "Error configuring OAuth1" : "Fehler bei der Konfiguration von OAuth1",
    "Error configuring OAuth2" : "Fehler bei der Konfiguration von OAuth2",
    "Generate keys" : "Generiere Schlüssel",
    "Error generating key pair" : "Fehler beim Generieren des Schlüsselpaars",
    "Enable encryption" : "Verschlüsselung aktivieren",
    "Enable previews" : "Vorschau aktivieren",
    "Check for changes" : "Auf Änderungen prüfen",
    "Never" : "Nie",
    "Once every direct access" : "Einmal bei jedem direkten Zugriff",
    "All users. Type to select user or group." : "Alle Benutzer. Tippe, um eine Benutzergruppe auszuwählen.",
    "(group)" : "(Gruppe)",
    "Saved" : "Gespeichert",
    "Username" : "Benutzername",
    "Password" : "Passwort",
    "Access key" : "Schlüssel für Zugriff",
    "Secret key" : "Geheimer Schlüssel",
    "Builtin" : "Eingebaut",
    "None" : "Keine(r)",
    "OAuth1" : "OAuth1",
    "App key" : "App Schlüssel",
    "App secret" : "App Secret",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client ID",
    "Client secret" : "Client Geheimnis",
    "OpenStack" : "OpenStack",
    "API key" : "API Schlüssel",
    "Username and password" : "Benutzername und Passwort",
    "RSA public key" : "Öffentlicher RSA Schlüssel",
    "Public key" : "Öffentlicher Schlüssel",
    "Amazon S3" : "Amazon S3",
    "Hostname" : "Hostname",
    "Port" : "Port",
    "Region" : "Region",
    "Enable SSL" : "SSL aktivieren",
    "Enable Path Style" : "Path Style aktivieren",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Entfernter Unterordner",
    "Secure https://" : "Sicheres https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Sicheres fpts://",
    "Google Drive" : "Google Drive",
    "Local" : "Lokal",
    "Location" : "Ort",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP mit Anmeldung über geheimen Schlüssel",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Teilen",
    "Domain" : "Domäne",
    "SMB / CIFS using OC login" : "SMB / DIFS mit OC Anmeldung",
    "Username as share" : "Benutzername als Freigabe",
    "Service name" : "Name des Dienstes",
    "Request timeout (seconds)" : "Zeitüberschreitung der Anfrage (Sekunden)",
    "<b>Note:</b> " : "<b>Notiz:</b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Notiz:</b> Die cURL-Unterstützung ist in PHP nicht aktiviert oder nicht installiert, deshalb ist das Einhängen von %s nicht möglich. Bitte deinen Administrator diese zu installieren.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Notiz:</b> Die FTP-Unterstützung ist in PHP nicht aktiviert oder nicht installiert, deshalb ist das Einhängen von %s nicht möglich. Bitte deinen Administrator diese zu installieren.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Notiz:</b> \"%s\" ist nicht installiert, deshalb ist das Einhängen von %s nicht möglich. Bitte deinen Administrator diese zu installieren.",
    "No external storage configured" : "Kein externer Speicher konfiguriert",
    "You can add external storages in the personal settings" : "Du kannst externe Speicher in deinen persönlichen Einstellungen hinzufügen",
    "Name" : "Name",
    "Storage type" : "Speicherart",
    "Scope" : "Bereich",
    "External Storage" : "Externer Speicher",
    "Folder name" : "Ordnername",
    "Authentication" : "Authentifizierung",
    "Configuration" : "Konfiguration",
    "Available for" : "Verfügbar für",
    "Add storage" : "Speicher hinzufügen",
    "Advanced settings" : "Erweiterte Einstellungen",
    "Delete" : "Löschen",
    "Allow users to mount the following external storage" : "Erlaube Benutzern folgenden externen Speicher einzuhängen",
    "SMB / CIFS" : "SMB / CIFS"
},
"nplurals=2; plural=(n != 1);");
